==> neo4j-kernel-4.4.10-sources.jar: org/neo4j/kernel/recovery/RecoveryStartInformation.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.recovery;

import org.neo4j.kernel.impl.transaction.log.LogPosition;

public class RecoveryStartInformation
{
    static final RecoveryStartInformation NO_RECOVERY_REQUIRED = new RecoveryStartInformation( LogPosition.UNSPECIFIED, LogPosition.UNSPECIFIED, -1 );
    static final RecoveryStartInformation MISSING_LOGS = new RecoveryStartInformation( null, null, -1, true );

    private final long firstTxIdAfterLastCheckPoint;
    private final LogPosition transactionLogPosition;
    private final LogPosition checkpointPosition;
    private final boolean missingLogs;

    public RecoveryStartInformation( LogPosition transactionLogPosition, LogPosition checkpointPosition, long firstTxIdAfterLastCheckPoint )
    {
        this( transactionLogPosition, checkpointPosition, firstTxIdAfterLastCheckPoint, false );
    }

    private RecoveryStartInformation( LogPosition transactionLogPosition, LogPosition checkpointPosition, long firstTxIdAfterLastCheckPoint,
            boolean missingLogs )
    {
        this.firstTxIdAfterLastCheckPoint = firstTxIdAfterLastCheckPoint;
        this.transactionLogPosition = transactionLogPosition;
        this.checkpointPosition = checkpointPosition;
        this.missingLogs = missingLogs;
    }

    public boolean isRecoveryRequired()
    {
        return transactionLogPosition != LogPosition.UNSPECIFIED;
    }

    long getFirstTxIdAfterLastCheckPoint()
    {
        return firstTxIdAfterLastCheckPoint;
    }

    LogPosition getTransactionLogPosition()
    {
        return transactionLogPosition;
    }

    public LogPosition getCheckpointPosition()
    {
        return checkpointPosition;
    }

    boolean isMissingLogs()
    {
        return missingLogs;
    }
}

==> neo4j-kernel-5.3.0-sources.jar: org/neo4j/kernel/recovery/RecoveryStartInformation.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.recovery;

import org.neo4j.kernel.impl.transaction.log.LogPosition;

public class RecoveryStartInformation {
    static final RecoveryStartInformation NO_RECOVERY_REQUIRED =
            new RecoveryStartInformation(LogPosition.UNSPECIFIED, LogPosition.UNSPECIFIED, -1);
    static final RecoveryStartInformation MISSING_LOGS = new RecoveryStartInformation(null, null, -1, true);

    private final long firstTxIdAfterLastCheckPoint;
    private final LogPosition transactionLogPosition;
    private final LogPosition checkpointPosition;
    private final boolean missingLogs;

    public RecoveryStartInformation(
            LogPosition transactionLogPosition, LogPosition checkpointPosition, long firstTxIdAfterLastCheckPoint) {
        this(transactionLogPosition, checkpointPosition, firstTxIdAfterLastCheckPoint, false);
    }

    private RecoveryStartInformation(
            LogPosition transactionLogPosition,
            LogPosition checkpointPosition,
            long firstTxIdAfterLastCheckPoint,
            boolean missingLogs) {
        this.firstTxIdAfterLastCheckPoint = firstTxIdAfterLastCheckPoint;
        this.transactionLogPosition = transactionLogPosition;
        this.checkpointPosition = checkpointPosition;
        this.missingLogs = missingLogs;
    }

    public boolean isRecoveryRequired() {
        return transactionLogPosition != LogPosition.UNSPECIFIED;
    }

    long getFirstTxIdAfterLastCheckPoint() {
        return firstTxIdAfterLastCheckPoint;
    }

    LogPosition getTransactionLogPosition() {
        return transactionLogPosition;
    }

    public LogPosition getCheckpointPosition() {
        return checkpointPosition;
    }

    boolean isMissingLogs() {
        return missingLogs;
    }
}
